@@ -1,4 +1,4 @@
-# Copyright (c) 2018 - 2022  Peter Pentchev <roam@ringlet.net>
+# Copyright (c) 2018 - 2023  Peter Pentchev <roam@ringlet.net>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -25,12 +25,25 @@
 """Common definitions for the confget configuration parsing library."""
 
 import dataclasses
+import enum
 import sys
 
 from typing import Dict, List, Optional
 
 
-VERSION_STRING = "5.0.0"
+class BackendType(str, enum.Enum):
+    """The supported confget backends."""
+
+    INI = "ini"
+    INI_PYP = "ini-pyp"
+    INI_REGEX = "ini-regex"
+
+    def __str__(self) -> str:
+        """Return a human-readable representation (the string itself)."""
+        return self.value
+
+
+VERSION_STRING = "5.1.0"
 FEATURES = [
     ("BASE", VERSION_STRING),
     ("REGEX", "1.0"),
@@ -38,7 +51,7 @@ FEATURES = [
         "REGEX_IMPL_PYTHON",
         f"{sys.version_info[0]}.{sys.version_info[1]}",
     ),
-    ("INI_BACKEND", "ini-pyp"),
+    ("INI_BACKEND", BackendType.INI_PYP),
     ("INI_PYP", "1.0"),
     ("INI_REGEX", "1.0"),
 ]
