@@ -24,6 +24,9 @@
 
 """Load a test definition from a JSON file."""
 
+# This is a test suite. We know what we are checking for.
+# pylint: disable=magic-value-comparison
+
 import json
 import os
 
@@ -40,7 +43,7 @@ def _load_test_v2(data: Dict[str, Any], _version: Dict[str, int]) -> tdefs.FileD
         raw = {
             key: value
             for key, value in test.items()
-            if key in ("args", "keys", "xform", "backend", "stdin")
+            if key in {"args", "keys", "xform", "backend", "stdin"}
         }
 
         if "exact" in test["output"]:
